# Activity Types
This is a list of every activity type in the database where you can modify, delete and add new activity types. Typing in the search field filters the activity types by name.

## Columns:
Each column title has three lines on the right if you hover over it. Click on them to show options for that column. The second tab of the options menu will allow you to filter the column, the third to completely hide entire columns. Click on anywhere else on the column to order it, cycling between ascending, descending and no ordering. Hold shift while clicking to order multiple columns with individual weights.

### Name:
The name of the activity type.

### Icon:
The icon representing the activity that is displayed in the calendar.

### Color:
The hexadecimal color code used to plot activity types. Must be unique.

### Multiplier:
Every activity type has a multiplier for the activity heat calculation. Multipliers range from low (2, i.e. e-mail) and medium (3, i.e. call) to high (4, i.e. meeting).

### Is Default:
If true sets the default value for type in new activities to be this instance.
